@@ -16,6 +16,6 @@ function(y)
     vrsum <- vrsum + 2*kfunc(i/lq)*sum1
     }
 vr <- sqrt(T/lq)*(vrsum - 1)/sqrt(2)
-return(list(AutoVR=vr))
+return(vr)
 }
 
